@@ -1,4 +1,3 @@
-import hashlib
 import jinja2
 
 import sssimp
@@ -9,7 +8,7 @@ import sssimp
 def a(context, value: str):
     """Makes a path absolute no matter where the file is"""
     value = value.removeprefix('/')
-    l1 = set(context['path'].parents)
+    l1 = set(context['page'].target.parents)
     l2 = set(sssimp.OUTPUT_DIR.parents)
     l2.add(sssimp.OUTPUT_DIR)
     diff = l1.difference(l2)
